@@ -8,7 +8,7 @@ import numpy as np
 import pyproj
 import rasterio as rio
 import rasterio.features as rio_features
-import rasterio.warp as rio_warp
+import rasterio.transform as rio_transform
 import simplejson as json
 import xarray as xr
 from shapely.geometry import LineString, Point, Polygon, box
@@ -57,7 +57,7 @@ def json2geodf(
     return geodf.drop_duplicates()
 
 
-def arcgis2geojson(arcgis: Dict[str, Any], idAttribute: Optional[str] = None) -> Dict[str, Any]:
+def arcgis2geojson(arcgis: Dict[str, Any], id_attr: Optional[str] = None) -> Dict[str, Any]:
     """Convert ESRIGeoJSON format to GeoJSON.
 
     Notes
@@ -68,7 +68,7 @@ def arcgis2geojson(arcgis: Dict[str, Any], idAttribute: Optional[str] = None) ->
     ----------
     arcgis : str or binary
         The ESRIGeoJSON format str (or binary)
-    idAttribute : str
+    id_attr : str
         ID of the attribute of interest
 
     Returns
@@ -77,14 +77,13 @@ def arcgis2geojson(arcgis: Dict[str, Any], idAttribute: Optional[str] = None) ->
         A GeoJSON file readable by GeoPandas
     """
 
-    def convert(arcgis, idAttribute=None):
+    def convert(arcgis, id_attr=None):
         """Convert an ArcGIS JSON object to a GeoJSON object."""
         geojson = {}
 
         if "features" in arcgis and arcgis["features"]:
             geojson["type"] = "FeatureCollection"
-            geojson["features"] = []
-            geojson["features"] = [convert(feature, idAttribute) for feature in arcgis["features"]]
+            geojson["features"] = [convert(feature, id_attr) for feature in arcgis["features"]]
 
         if (
             "x" in arcgis
@@ -144,7 +143,7 @@ def arcgis2geojson(arcgis: Dict[str, Any], idAttribute: Optional[str] = None) ->
                 geojson["properties"] = arcgis["attributes"]
                 try:
                     attributes = arcgis["attributes"]
-                    keys = [idAttribute, "OBJECTID", "FID"] if idAttribute else ["OBJECTID", "FID"]
+                    keys = [id_attr, "OBJECTID", "FID"] if id_attr else ["OBJECTID", "FID"]
                     for key in keys:
                         if key in attributes and (
                             isinstance(attributes[key], (numbers.Number, str))
@@ -163,10 +162,10 @@ def arcgis2geojson(arcgis: Dict[str, Any], idAttribute: Optional[str] = None) ->
 
     def rings2geojson(rings):
         """Check for holes in the ring and fill them."""
-        outerRings = []
+        outer_rings = []
         holes = []
         x = None  # iterable
-        outerRing = None  # current outer ring being evaluated
+        outer_ring = None  # current outer ring being evaluated
         hole = None  # current hole being evaluated
 
         for ring in rings:
@@ -181,13 +180,13 @@ def arcgis2geojson(arcgis: Dict[str, Any], idAttribute: Optional[str] = None) ->
             )
             # Clock-wise check
             if total >= 0:
-                outerRings.append(
+                outer_rings.append(
                     [ring[::-1]]
                 )  # wind outer rings counterclockwise for RFC 7946 compliance
             else:
                 holes.append(ring[::-1])  # wind inner rings clockwise for RFC 7946 compliance
 
-        uncontainedHoles = []
+        uncontained_holes = []
 
         # while there are holes left...
         while holes:
@@ -196,16 +195,16 @@ def arcgis2geojson(arcgis: Dict[str, Any], idAttribute: Optional[str] = None) ->
 
             # loop over all outer rings and see if they contain our hole.
             contained = False
-            x = len(outerRings) - 1
+            x = len(outer_rings) - 1
             while x >= 0:
-                outerRing = outerRings[x][0]
-                l1, l2 = LineString(outerRing), LineString(hole)
+                outer_ring = outer_rings[x][0]
+                l1, l2 = LineString(outer_ring), LineString(hole)
                 p2 = Point(hole[0])
                 intersects = l1.intersects(l2)
                 contains = l1.contains(p2)
                 if not intersects and contains:
                     # the hole is contained push it into our polygon
-                    outerRings[x].append(hole)
+                    outer_rings[x].append(hole)
                     contained = True
                     break
                 x = x - 1
@@ -213,39 +212,39 @@ def arcgis2geojson(arcgis: Dict[str, Any], idAttribute: Optional[str] = None) ->
             # ring is not contained in any outer ring
             # sometimes this happens https://github.com/Esri/esri-leaflet/issues/320
             if not contained:
-                uncontainedHoles.append(hole)
+                uncontained_holes.append(hole)
 
         # if we couldn't match any holes using contains we can try intersects...
-        while uncontainedHoles:
+        while uncontained_holes:
             # pop a hole off out stack
-            hole = uncontainedHoles.pop()
+            hole = uncontained_holes.pop()
 
             # loop over all outer rings and see if any intersect our hole.
             intersects = False
-            x = len(outerRings) - 1
+            x = len(outer_rings) - 1
             while x >= 0:
-                outerRing = outerRings[x][0]
-                l1, l2 = LineString(outerRing), LineString(hole)
+                outer_ring = outer_rings[x][0]
+                l1, l2 = LineString(outer_ring), LineString(hole)
                 intersects = l1.intersects(l2)
                 if intersects:
                     # the hole is contained push it into our polygon
-                    outerRings[x].append(hole)
+                    outer_rings[x].append(hole)
                     intersects = True
                     break
                 x = x - 1
 
             if not intersects:
-                outerRings.append([hole[::-1]])
+                outer_rings.append([hole[::-1]])
 
-        if len(outerRings) == 1:
-            return {"type": "Polygon", "coordinates": outerRings[0]}
+        if len(outer_rings) == 1:
+            return {"type": "Polygon", "coordinates": outer_rings[0]}
 
-        return {"type": "MultiPolygon", "coordinates": outerRings}
+        return {"type": "MultiPolygon", "coordinates": outer_rings}
 
     if isinstance(arcgis, str):
-        return json.dumps(convert(json.loads(arcgis), idAttribute))
+        return json.dumps(convert(json.loads(arcgis), id_attr))
 
-    return convert(arcgis, idAttribute)
+    return convert(arcgis, id_attr)
 
 
 def gtiff2xarray(
@@ -271,7 +270,9 @@ def gtiff2xarray(
     """
     var_name = {lyr: f"{''.join(n for n in lyr.split('_')[:-1])}" for lyr in r_dict.keys()}
 
-    ds = xr.merge([_create_dataset(r, var_name[lyr]) for lyr, r in r_dict.items()])
+    ds = xr.merge(
+        [_create_dataset(r, var_name[lyr]) for lyr, r in r_dict.items()], combine_attrs="override"
+    )
     ds = _geometry_mask(ds, geometry, geo_crs)
 
     if len(ds.variables) - len(ds.dims) == 1:
@@ -312,15 +313,19 @@ def _create_dataset(content: bytes, name: str,) -> Union[xr.Dataset, xr.DataArra
     return ds
 
 
-def _geometry_mask(ds: Union[xr.Dataset, xr.DataArray], geometry: Polygon, geo_crs: str):
+def _geometry_mask(
+    ds: Union[xr.Dataset, xr.DataArray],
+    geometry: Union[Polygon, Tuple[float, float, float, float]],
+    geo_crs: str,
+):
     """Mask a ``xarray.Dataset`` based on a geometry.
 
     Parameters
     ----------
     ds : xarray.Dataset or xarray.DataArray
         The dataset(array) to be masked
-    geometry : Polygon
-        The geometry to mask the data
+    geometry : Polygon or tuple of length 4
+        The geometry or bounding box to mask the data
     geo_crs : str
         The spatial reference of the input geometry
 
@@ -330,27 +335,19 @@ def _geometry_mask(ds: Union[xr.Dataset, xr.DataArray], geometry: Polygon, geo_c
         The input dataset with a mask applied (np.nan)
     """
     if isinstance(geometry, tuple):
-        check_bbox(geometry)  # type: ignore
-        _geometry = box(*geometry)
+        _geometry = box(*MatchCRS.bounds(geometry, geo_crs, ds.crs))  # type: ignore
     elif isinstance(geometry, Polygon):
-        _geometry = geometry
+        _geometry = MatchCRS.geometry(geometry, geo_crs, ds.crs)
     else:
         raise InvalidInputType("geometry", "Polygon or tuple of length 4")
 
-    left, bottom, right, top = _geometry.bounds
-    height, width = list(ds.sizes.values())[-2:]
-    transform = rio_warp.calculate_default_transform(
-        geo_crs, geo_crs, width, height, left, bottom, right, top
-    )[0]
+    west, south, east, north = _geometry.bounds
+    height, width = ds.sizes["y"], ds.sizes["x"]
+    transform = rio_transform.from_bounds(west, south, east, north, width, height)
     _mask = rio_features.geometry_mask([_geometry], (height, width), transform, invert=True)
-    mask = xr.DataArray(_mask, dims=list(ds.sizes.keys())[-2:])
+    mask = xr.DataArray(_mask, dims=("y", "x"))
 
-    def mask_da(da):
-        da = da.where(mask, drop=True)
-        da.attrs["nodatavals"] = (np.nan,)
-        return da
-
-    return ds.map(mask_da)
+    return ds.where(mask)
 
 
 class MatchCRS:
